"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[539],{

/***/ 36539:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgOpenai; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgOpenai = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "openai_svg__icon", viewBox: "0 0 1024 1024", xmlns: "http://www.w3.org/2000/svg", width: 200, height: 200 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M950.676 419.057a255.347 255.347 0 0 0-22.015-209.482A257.95 257.95 0 0 0 650.915 85.848a258.76 258.76 0 0 0-438.377 92.539A255.347 255.347 0 0 0 41.966 302.114a257.95 257.95 0 0 0 31.7 302.79 255.133 255.133 0 0 0 21.758 209.525 258.163 258.163 0 0 0 277.96 123.727 255.347 255.347 0 0 0 192.373 85.84 258.376 258.376 0 0 0 246.26-179.446 255.56 255.56 0 0 0 170.53-123.727 258.376 258.376 0 0 0-31.871-301.766zM565.757 957.013a190.966 190.966 0 0 1-122.703-44.37l6.016-3.456 203.893-117.67a33.918 33.918 0 0 0 16.725-29.054v-287.43l86.182 49.832a3.03 3.03 0 0 1 1.621 2.219v238.195a192.16 192.16 0 0 1-191.734 191.734zM153.62 780.98a190.71 190.71 0 0 1-22.826-128.59l6.058 3.626 204.065 117.71a32.894 32.894 0 0 0 33.278 0L623.482 629.99v99.494a3.413 3.413 0 0 1-1.408 2.645L415.578 851.206a191.99 191.99 0 0 1-261.96-70.226zM99.86 336.928a191.35 191.35 0 0 1 100.944-84.177v242.206a32.681 32.681 0 0 0 16.554 28.841l248.094 143.14-86.182 49.832a3.242 3.242 0 0 1-3.03 0L170.173 597.907a192.16 192.16 0 0 1-70.31-262.003zM807.963 501.4 559.102 356.895l85.968-49.661a3.242 3.242 0 0 1 3.03 0L854.169 426.31a191.734 191.734 0 0 1-28.841 345.796v-242.25a33.705 33.705 0 0 0-17.365-28.456zm85.756-128.975-6.016-3.627-203.68-118.692a33.108 33.108 0 0 0-33.491 0L401.456 393.842v-99.536a2.816 2.816 0 0 1 1.195-2.602l206.07-118.906a191.99 191.99 0 0 1 284.998 198.816zM354.44 548.842l-86.182-49.661a3.413 3.413 0 0 1-1.621-2.432V259.236a191.99 191.99 0 0 1 314.65-147.32l-6.058 3.413-203.851 117.668a33.918 33.918 0 0 0-16.767 29.055zm46.803-100.901 111.013-63.997 111.226 63.997v127.95l-110.8 63.997-111.226-63.996z" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,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");


/***/ })

}]);