"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[786],{

/***/ 27786:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgDeepseek; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgDeepseek = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "deepseek_svg__icon", viewBox: "0 0 1024 1024", xmlns: "http://www.w3.org/2000/svg", width: 200, height: 200 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M320.512 804.864c-274.432-128-242.688-530.432 41.984-530.432 34.816 0 86.016-7.168 114.688-14.336 59.392-16.384 99.328-10.24 69.632 10.24-9.216 7.168-15.36 19.456-13.312 28.672 5.12 20.48 158.72 161.792 177.152 161.792 27.648 0 27.648-32.768 1.024-57.344-43.008-38.912-55.296-90.112-35.84-141.312l9.216-26.624 54.272 52.224c35.84 34.816 58.368 49.152 68.608 44.032 9.216-4.096 30.72-9.216 49.152-12.288 18.432-2.048 38.912-10.24 45.056-18.432 19.456-23.552 43.008-17.408 35.84 9.216-3.072 12.288-6.144 27.648-6.144 34.816 0 23.552-62.464 83.968-92.16 90.112-23.552 5.12-30.72 12.288-30.72 30.72 0 46.08-38.912 148.48-75.776 198.656l-37.888 51.2 36.864 15.36c56.32 23.552 40.96 41.984-37.888 43.008-43.008 1.024-75.776 7.168-92.16 18.432-68.608 45.056-198.656 50.176-281.6 12.288zm251.904-86.016c-24.576-27.648-66.56-79.872-93.184-117.76-69.632-98.304-158.72-150.528-256-150.528-37.888 0-38.912 1.024-38.912 34.816 0 94.208 99.328 240.64 175.104 257.024 38.912 9.216 59.392-7.168 39.936-29.696-7.168-9.216-10.24-23.552-6.144-31.744 5.12-14.336 9.216-14.336 38.912 1.024 18.432 9.216 50.176 29.696 69.632 45.056 35.84 27.648 58.368 37.888 96.256 39.936 14.336 1.024 9.216-10.24-25.6-48.128zM660.48 573.44c8.192-13.312-31.744-78.848-56.32-92.16-10.24-6.144-26.624-10.24-34.816-10.24-23.552 0-20.48 27.648 4.096 33.792 13.312 3.072 20.48 14.336 20.48 29.696 0 13.312 5.12 29.696 12.288 36.864 15.36 15.36 46.08 16.384 54.272 2.048z", fill: "#4D6BFE" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,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");


/***/ })

}]);