"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[654],{

/***/ 58654:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgBaichuan; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgBaichuan = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "baichuan_svg__icon", viewBox: "0 0 1024 1024", xmlns: "http://www.w3.org/2000/svg", width: 200, height: 200 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M0 0h1024v1024H0z", fill: "#FFF" }), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M466.96999999999997 147.2h164.812q6.912 0 6.912 6.912v701.594q0 6.912-6.912 6.912H466.97q-6.912 0-6.912-6.912V154.112q0-6.912 6.912-6.912ZM717.85 147.2h163.814q7.936 0 7.936 7.936v128.768q0 7.936-7.936 7.936H717.85q-7.936 0-7.936-7.936V155.136q0-7.936 7.936-7.936ZM123.725 862.413v-10.957l73.395-139.418c2.893-5.53 4.352-11.417 4.352-17.664l.128-386.406c0-6.195 1.434-12.032 4.352-17.536a76711.168 76711.168 0 0 0 72.243-137.446 2.637 2.637 0 0 1 2.304-1.408h105.063c1.484 0 2.201.768 2.201 2.252.051 179.38.077 358.759.051 538.112 0 6.426-1.536 12.493-4.556 18.125a83817.088 83817.088 0 0 0-80.82 151.168 3.84 3.84 0 0 1-3.302 2.176c-15.283 1.46-32.333-.947-45.517-.486a1603.766 1603.766 0 0 1-129.869-.512zM720.922 342.272h157.67q11.008 0 11.008 11.008v498.38q0 11.009-11.008 11.009h-157.67q-11.008 0-11.008-11.008V353.28q0-11.008 11.008-11.008Z", fill: "#E06739" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,PHN2ZyBjbGFzcz0iaWNvbiIgdmlld0JveD0iMCAwIDEwMjQgMTAyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMjAwIiBoZWlnaHQ9IjIwMCI+PHBhdGggZD0iTTAgMGgxMDI0djEwMjRIMHoiIGZpbGw9IiNGRkYiLz48cGF0aCBkPSJNNDY2Ljk2OTk5OTk5OTk5OTk3IDE0Ny4yaDE2NC44MTJxNi45MTIgMCA2LjkxMiA2LjkxMnY3MDEuNTk0cTAgNi45MTItNi45MTIgNi45MTJINDY2Ljk3cS02LjkxMiAwLTYuOTEyLTYuOTEyVjE1NC4xMTJxMC02LjkxMiA2LjkxMi02LjkxMlpNNzE3Ljg1IDE0Ny4yaDE2My44MTRxNy45MzYgMCA3LjkzNiA3LjkzNnYxMjguNzY4cTAgNy45MzYtNy45MzYgNy45MzZINzE3Ljg1cS03LjkzNiAwLTcuOTM2LTcuOTM2VjE1NS4xMzZxMC03LjkzNiA3LjkzNi03LjkzNlpNMTIzLjcyNSA4NjIuNDEzdi0xMC45NTdsNzMuMzk1LTEzOS40MThjMi44OTMtNS41MyA0LjM1Mi0xMS40MTcgNC4zNTItMTcuNjY0bC4xMjgtMzg2LjQwNmMwLTYuMTk1IDEuNDM0LTEyLjAzMiA0LjM1Mi0xNy41MzZhNzY3MTEuMTY4IDc2NzExLjE2OCAwIDAgMCA3Mi4yNDMtMTM3LjQ0NiAyLjYzNyAyLjYzNyAwIDAgMSAyLjMwNC0xLjQwOGgxMDUuMDYzYzEuNDg0IDAgMi4yMDEuNzY4IDIuMjAxIDIuMjUyLjA1MSAxNzkuMzguMDc3IDM1OC43NTkuMDUxIDUzOC4xMTIgMCA2LjQyNi0xLjUzNiAxMi40OTMtNC41NTYgMTguMTI1YTgzODE3LjA4OCA4MzgxNy4wODggMCAwIDAtODAuODIgMTUxLjE2OCAzLjg0IDMuODQgMCAwIDEtMy4zMDIgMi4xNzZjLTE1LjI4MyAxLjQ2LTMyLjMzMy0uOTQ3LTQ1LjUxNy0uNDg2YTE2MDMuNzY2IDE2MDMuNzY2IDAgMCAxLTEyOS44NjktLjUxMnpNNzIwLjkyMiAzNDIuMjcyaDE1Ny42N3ExMS4wMDggMCAxMS4wMDggMTEuMDA4djQ5OC4zOHEwIDExLjAwOS0xMS4wMDggMTEuMDA5aC0xNTcuNjdxLTExLjAwOCAwLTExLjAwOC0xMS4wMDhWMzUzLjI4cTAtMTEuMDA4IDExLjAwOC0xMS4wMDhaIiBmaWxsPSIjRTA2NzM5Ii8+PC9zdmc+");


/***/ })

}]);