"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[377],{

/***/ 64377:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgErnie; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgErnie = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "ernie_svg__icon", viewBox: "0 0 1024 1024", xmlns: "http://www.w3.org/2000/svg", width: 200, height: 200 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M514.503 56.889 113.778 283.307v457.102L501.19 967.11 910.222 735.46V297.529L514.503 56.889zm-91.477 729.486L233.358 675.328V349.582L512.284 192l168.392 102.343-224.37 135.68a61.212 61.212 0 0 0-33.28 54.215v302.137zm367.673-117.191L542.549 809.87V514.048l248.093-149.845v304.981h.057z" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,PHN2ZyBjbGFzcz0iaWNvbiIgdmlld0JveD0iMCAwIDEwMjQgMTAyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMjAwIiBoZWlnaHQ9IjIwMCI+PHBhdGggZD0iTTUxNC41MDMgNTYuODg5IDExMy43NzggMjgzLjMwN3Y0NTcuMTAyTDUwMS4xOSA5NjcuMTEgOTEwLjIyMiA3MzUuNDZWMjk3LjUyOUw1MTQuNTAzIDU2Ljg4OXptLTkxLjQ3NyA3MjkuNDg2TDIzMy4zNTggNjc1LjMyOFYzNDkuNTgyTDUxMi4yODQgMTkybDE2OC4zOTIgMTAyLjM0My0yMjQuMzcgMTM1LjY4YTYxLjIxMiA2MS4yMTIgMCAwIDAtMzMuMjggNTQuMjE1djMwMi4xMzd6bTM2Ny42NzMtMTE3LjE5MUw1NDIuNTQ5IDgwOS44N1Y1MTQuMDQ4bDI0OC4wOTMtMTQ5Ljg0NXYzMDQuOTgxaC4wNTd6Ii8+PC9zdmc+");


/***/ })

}]);