"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[976],{

/***/ 74976:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgMoonshot; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgMoonshot = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "moonshot_svg__icon", viewBox: "0 0 1024 1024", xmlns: "http://www.w3.org/2000/svg", width: 200, height: 200 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "m117.965 684.646 342.303 93.574v75.345l209.715 58.573A428.995 428.995 0 0 1 512 942.08c-176.128 0-327.537-105.882-394.035-257.434zM83.292 477.43l407.306 112.64-9.625 37.007-6.042 35.02 383.386 104.96a432.538 432.538 0 0 1-65.106 70.33l-688.19-185.96A429.466 429.466 0 0 1 81.92 512c0-11.633.471-23.142 1.372-34.55zm57.344-182.477L569.713 409.17a279.941 279.941 0 0 0-23.06 35.553 201.175 201.175 0 0 0-14.705 34.94l403.087 110.263a426.803 426.803 0 0 1-23.552 81.716L86.548 448.717a427.254 427.254 0 0 1 54.068-153.764zM299.11 138.199l404.235 108.319a190.26 190.26 0 0 0-32.81 24.903c-9.133 8.807-19.865 21.402-32.153 37.745l285.246 77.783a430.207 430.207 0 0 1 17.326 93.594L156.61 269.68a432.271 432.271 0 0 1 142.5-131.482zM512 81.92c142.91 0 269.558 69.714 347.75 176.988L337.265 118.907A428.503 428.503 0 0 1 512 81.92z" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,PHN2ZyBjbGFzcz0iaWNvbiIgdmlld0JveD0iMCAwIDEwMjQgMTAyNCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMjAwIiBoZWlnaHQ9IjIwMCI+PHBhdGggZD0ibTExNy45NjUgNjg0LjY0NiAzNDIuMzAzIDkzLjU3NHY3NS4zNDVsMjA5LjcxNSA1OC41NzNBNDI4Ljk5NSA0MjguOTk1IDAgMCAxIDUxMiA5NDIuMDhjLTE3Ni4xMjggMC0zMjcuNTM3LTEwNS44ODItMzk0LjAzNS0yNTcuNDM0ek04My4yOTIgNDc3LjQzbDQwNy4zMDYgMTEyLjY0LTkuNjI1IDM3LjAwNy02LjA0MiAzNS4wMiAzODMuMzg2IDEwNC45NmE0MzIuNTM4IDQzMi41MzggMCAwIDEtNjUuMTA2IDcwLjMzbC02ODguMTktMTg1Ljk2QTQyOS40NjYgNDI5LjQ2NiAwIDAgMSA4MS45MiA1MTJjMC0xMS42MzMuNDcxLTIzLjE0MiAxLjM3Mi0zNC41NXptNTcuMzQ0LTE4Mi40NzdMNTY5LjcxMyA0MDkuMTdhMjc5Ljk0MSAyNzkuOTQxIDAgMCAwLTIzLjA2IDM1LjU1MyAyMDEuMTc1IDIwMS4xNzUgMCAwIDAtMTQuNzA1IDM0Ljk0bDQwMy4wODcgMTEwLjI2M2E0MjYuODAzIDQyNi44MDMgMCAwIDEtMjMuNTUyIDgxLjcxNkw4Ni41NDggNDQ4LjcxN2E0MjcuMjU0IDQyNy4yNTQgMCAwIDEgNTQuMDY4LTE1My43NjR6TTI5OS4xMSAxMzguMTk5bDQwNC4yMzUgMTA4LjMxOWExOTAuMjYgMTkwLjI2IDAgMCAwLTMyLjgxIDI0LjkwM2MtOS4xMzMgOC44MDctMTkuODY1IDIxLjQwMi0zMi4xNTMgMzcuNzQ1bDI4NS4yNDYgNzcuNzgzYTQzMC4yMDcgNDMwLjIwNyAwIDAgMSAxNy4zMjYgOTMuNTk0TDE1Ni42MSAyNjkuNjhhNDMyLjI3MSA0MzIuMjcxIDAgMCAxIDE0Mi41LTEzMS40ODJ6TTUxMiA4MS45MmMxNDIuOTEgMCAyNjkuNTU4IDY5LjcxNCAzNDcuNzUgMTc2Ljk4OEwzMzcuMjY1IDExOC45MDdBNDI4LjUwMyA0MjguNTAzIDAgMCAxIDUxMiA4MS45MnoiLz48L3N2Zz4=");


/***/ })

}]);