"use strict";
(self["webpackChunk_difizen_magent_ui"] = self["webpackChunk_difizen_magent_ui"] || []).push([[892],{

/***/ 18892:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   ReactComponent: function() { return /* binding */ SvgQwen; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44194);
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

const SvgQwen = (props) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("svg", __spreadValues({ className: "qwen_svg__icon", xmlns: "http://www.w3.org/2000/svg", width: 1024, height: 1024 }, props), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "M1019.407 620.8 891.834 397.781 946.49 293.12a29.099 29.099 0 0 0 6.4-36.395l-70.187-126.592a30.08 30.08 0 0 0-24.576-13.653H597.519L539.194 14.507a27.35 27.35 0 0 0-20.907-14.55H380.644a29.141 29.141 0 0 0-24.618 14.55v5.546L225.806 243.03H100.923a29.184 29.184 0 0 0-25.515 13.654L3.428 384.085a32.768 32.768 0 0 0 0 29.184L132.836 638.08 74.511 740.053a32.768 32.768 0 0 0 0 29.056l66.517 116.566a29.907 29.907 0 0 0 25.515 14.506H427.15l62.848 109.227A30.08 30.08 0 0 0 512.783 1024H660.41a29.141 29.141 0 0 0 24.576-14.55l128.469-224.853h114.773a31.915 31.915 0 0 0 24.662-15.445l66.474-117.419a28.16 28.16 0 0 0 0-30.976l.043.043zm-161.28 14.592L791.61 512.469 518.287 993.963l-74.752-122.88h-273.28l65.621-119.211h139.392L101.86 272.213h143.062L380.687 30.08l68.352 119.253-70.187 122.88H925.54l-69.205 121.942 137.6 241.194H858.17z", fill: "#605BEC" }), /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_0__.createElement("path", { d: "m499.983 699.307 174.379-274.731H324.708z", fill: "#605BEC" }));

/* harmony default export */ __webpack_exports__["default"] = ("data:image/svg+xml;base64,PHN2ZyBjbGFzcz0iaWNvbiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTAyNCIgaGVpZ2h0PSIxMDI0Ij48cGF0aCBkPSJNMTAxOS40MDcgNjIwLjggODkxLjgzNCAzOTcuNzgxIDk0Ni40OSAyOTMuMTJhMjkuMDk5IDI5LjA5OSAwIDAgMCA2LjQtMzYuMzk1bC03MC4xODctMTI2LjU5MmEzMC4wOCAzMC4wOCAwIDAgMC0yNC41NzYtMTMuNjUzSDU5Ny41MTlMNTM5LjE5NCAxNC41MDdhMjcuMzUgMjcuMzUgMCAwIDAtMjAuOTA3LTE0LjU1SDM4MC42NDRhMjkuMTQxIDI5LjE0MSAwIDAgMC0yNC42MTggMTQuNTV2NS41NDZMMjI1LjgwNiAyNDMuMDNIMTAwLjkyM2EyOS4xODQgMjkuMTg0IDAgMCAwLTI1LjUxNSAxMy42NTRMMy40MjggMzg0LjA4NWEzMi43NjggMzIuNzY4IDAgMCAwIDAgMjkuMTg0TDEzMi44MzYgNjM4LjA4IDc0LjUxMSA3NDAuMDUzYTMyLjc2OCAzMi43NjggMCAwIDAgMCAyOS4wNTZsNjYuNTE3IDExNi41NjZhMjkuOTA3IDI5LjkwNyAwIDAgMCAyNS41MTUgMTQuNTA2SDQyNy4xNWw2Mi44NDggMTA5LjIyN0EzMC4wOCAzMC4wOCAwIDAgMCA1MTIuNzgzIDEwMjRINjYwLjQxYTI5LjE0MSAyOS4xNDEgMCAwIDAgMjQuNTc2LTE0LjU1bDEyOC40NjktMjI0Ljg1M2gxMTQuNzczYTMxLjkxNSAzMS45MTUgMCAwIDAgMjQuNjYyLTE1LjQ0NWw2Ni40NzQtMTE3LjQxOWEyOC4xNiAyOC4xNiAwIDAgMCAwLTMwLjk3NmwuMDQzLjA0M3ptLTE2MS4yOCAxNC41OTJMNzkxLjYxIDUxMi40NjkgNTE4LjI4NyA5OTMuOTYzbC03NC43NTItMTIyLjg4aC0yNzMuMjhsNjUuNjIxLTExOS4yMTFoMTM5LjM5MkwxMDEuODYgMjcyLjIxM2gxNDMuMDYyTDM4MC42ODcgMzAuMDhsNjguMzUyIDExOS4yNTMtNzAuMTg3IDEyMi44OEg5MjUuNTRsLTY5LjIwNSAxMjEuOTQyIDEzNy42IDI0MS4xOTRIODU4LjE3eiIgZmlsbD0iIzYwNUJFQyIvPjxwYXRoIGQ9Im00OTkuOTgzIDY5OS4zMDcgMTc0LjM3OS0yNzQuNzMxSDMyNC43MDh6IiBmaWxsPSIjNjA1QkVDIi8+PC9zdmc+");


/***/ })

}]);